@@ -1,4 +1,4 @@
-__version__ = '1.0.28'
+__version__ = '1.0.31'
 __author__ = 'arnold'
 
 import json
@@ -118,7 +118,7 @@ class TerraformQueryExtension(Extension):
                 if((value_name is not None) and (output["attributes"]["value"][value_name] is not None)):
                     return output["attributes"]["value"][value_name]
                 elif((len(output["attributes"]["value"])!=0)):
-                    print(len(output["attributes"]["value"]))
+                    print("Length= ", len(output["attributes"]["value"]))
                     return output["attributes"]["value"]
                 else:
                     sys.exit("Value is None for attribute " +name)
